[Ffmpeg-cvslog] CVS: ffmpeg/libavcodec 4xm.c, 1.14, 1.15 lcl.c, 1.10, 1.11 h263.c, 1.274, 1.275 h264.c, 1.111, 1.112 mpeg12.c, 1.233, 1.234 faad.c, 1.6, 1.7 ffv1.c, 1.31, 1.32 flac.c, 1.17, 1.18 h263dec.c, 1.165, 1.166 huffyuv.c, 1.60, 1.61 rv10.c, 1.68, 1.69 snow.c, 1.57, 1.58 wmv2.c, 1.29, 1.30 motion_est.c, 1.103, 1.104 vc9.c, 1.17, 1.18 mpegvideo.c, 1.475, 1.476 error_resilience.c, 1.28, 1.29 msmpeg4.c, 1.85, 1.86 xvmcvideo.c, 1.10, 1.11 h261.c, 1.23, 1.24 ratecontrol.c, 1.47, 1.48 mpegvideo.h, 1.221, 1.222 avcodec.h, 1.390, 1.391

Mike Melanson CVS melanson
Sun Apr 24 19:21:16 CEST 2005


Update of /cvsroot/ffmpeg/ffmpeg/libavcodec
In directory mail:/var2/tmp/cvs-serv19239/libavcodec

Modified Files:
	4xm.c lcl.c h263.c h264.c mpeg12.c faad.c ffv1.c flac.c 
	h263dec.c huffyuv.c rv10.c snow.c wmv2.c motion_est.c vc9.c 
	mpegvideo.c error_resilience.c msmpeg4.c xvmcvideo.c h261.c 
	ratecontrol.c mpegvideo.h avcodec.h 
Log Message:
Ministry of English Composition, reporting for duty (and the word is "skipped", not "skiped"; "skiped" would rhyme with "hyped")


Index: 4xm.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/4xm.c,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -d -r1.14 -r1.15
--- 4xm.c	23 Jan 2005 18:09:05 -0000	1.14
+++ 4xm.c	24 Apr 2005 17:21:07 -0000	1.15
@@ -564,7 +564,7 @@
     if(prestream_size + bitstream_size + 12 != length
        || bitstream_size > (1<<26)
        || prestream_size > (1<<26)){
-        av_log(f->avctx, AV_LOG_ERROR, "size missmatch %d %d %d\n", prestream_size, bitstream_size, length);
+        av_log(f->avctx, AV_LOG_ERROR, "size mismatch %d %d %d\n", prestream_size, bitstream_size, length);
         return -1;
     }
    
@@ -591,7 +591,7 @@
     }
 
     if(get_vlc2(&f->pre_gb, f->pre_vlc.table, ACDC_VLC_BITS, 3) != 256)
-        av_log(f->avctx, AV_LOG_ERROR, "end missmatch\n");
+        av_log(f->avctx, AV_LOG_ERROR, "end mismatch\n");
     
     return 0;
 }
@@ -607,7 +607,7 @@
 
     frame_4cc= get32(buf);
     if(buf_size != get32(buf+4)+8){
-        av_log(f->avctx, AV_LOG_ERROR, "size missmatch %d %d\n", buf_size, get32(buf+4));
+        av_log(f->avctx, AV_LOG_ERROR, "size mismatch %d %d\n", buf_size, get32(buf+4));
     }
 
     if(frame_4cc == ff_get_fourcc("cfrm")){
@@ -643,7 +643,7 @@
             frame_size= cfrm->size;
             
             if(id != avctx->frame_number){
-                av_log(f->avctx, AV_LOG_ERROR, "cframe id missmatch %d %d\n", id, avctx->frame_number);
+                av_log(f->avctx, AV_LOG_ERROR, "cframe id mismatch %d %d\n", id, avctx->frame_number);
             }
             
             cfrm->size= cfrm->id= 0;

Index: lcl.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/lcl.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -d -r1.10 -r1.11
--- lcl.c	6 Mar 2005 23:20:53 -0000	1.10
+++ lcl.c	24 Apr 2005 17:21:07 -0000	1.11
@@ -714,7 +714,7 @@
                     break;
                 default:
                     if ((c->compression < Z_NO_COMPRESSION) || (c->compression > Z_BEST_COMPRESSION)) {
-                	    av_log(avctx, AV_LOG_ERROR, "Unusupported compression level for ZLIB: (%d).\n", c->compression);
+                	    av_log(avctx, AV_LOG_ERROR, "Unsupported compression level for ZLIB: (%d).\n", c->compression);
                         return 1;
                     }
                     av_log(avctx, AV_LOG_INFO, "Compression level for ZLIB: (%d).\n", c->compression);

Index: h264.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/h264.c,v
retrieving revision 1.111
retrieving revision 1.112
diff -u -d -r1.111 -r1.112
--- h264.c	21 Apr 2005 20:38:42 -0000	1.111
+++ h264.c	24 Apr 2005 17:21:08 -0000	1.112
@@ -162,7 +162,7 @@
 
     int chroma_qp; //QPc
 
-    int prev_mb_skiped; //FIXME remove (IMHO not used)
+    int prev_mb_skipped; //FIXME remove (IMHO not used)
 
     //prediction stuff
     int chroma_pred_mode;
@@ -4205,7 +4205,7 @@
     s->current_picture.mb_type[mb_xy]= mb_type|MB_TYPE_SKIP;
     s->current_picture.qscale_table[mb_xy]= s->qscale;
     h->slice_table[ mb_xy ]= h->slice_num;
-    h->prev_mb_skiped= 1;
+    h->prev_mb_skipped= 1;
 }
 
 /**
@@ -4232,12 +4232,12 @@
         }
     }
     if(h->mb_aff_frame){
-        if ( ((s->mb_y&1) == 0) || h->prev_mb_skiped)
+        if ( ((s->mb_y&1) == 0) || h->prev_mb_skipped)
             h->mb_field_decoding_flag = get_bits1(&s->gb);
     }else
         h->mb_field_decoding_flag= (s->picture_structure!=PICT_FRAME);
     
-    h->prev_mb_skiped= 0;
+    h->prev_mb_skipped= 0;
     
     mb_type= get_ue_golomb(&s->gb);
     if(h->slice_type == B_TYPE){
@@ -5209,12 +5209,12 @@
         }
     }
     if(h->mb_aff_frame){
-        if ( ((s->mb_y&1) == 0) || h->prev_mb_skiped)
+        if ( ((s->mb_y&1) == 0) || h->prev_mb_skipped)
             h->mb_field_decoding_flag = decode_cabac_field_decoding_flag(h);
     }else
         h->mb_field_decoding_flag= (s->picture_structure!=PICT_FRAME);
 
-    h->prev_mb_skiped = 0;
+    h->prev_mb_skipped = 0;
 
     compute_mb_neighboors(h);
     if( ( mb_type = decode_cabac_mb_type( h ) ) < 0 ) {
@@ -6628,7 +6628,7 @@
         sps->crop_top   = get_ue_golomb(&s->gb);
         sps->crop_bottom= get_ue_golomb(&s->gb);
         if(sps->crop_left || sps->crop_top){
-            av_log(h->s.avctx, AV_LOG_ERROR, "insane cropping not completly supported, this could look slightly wrong ...\n");
+            av_log(h->s.avctx, AV_LOG_ERROR, "insane cropping not completely supported, this could look slightly wrong ...\n");
         }
     }else{
         sps->crop_left  = 
@@ -7022,7 +7022,7 @@
 
     //FIXME do something with unavailable reference frames    
  
-//    if(ret==FRAME_SKIPED) return get_consumed_bytes(s, buf_index, buf_size);
+//    if(ret==FRAME_SKIPPED) return get_consumed_bytes(s, buf_index, buf_size);
     if(!s->current_picture_ptr){
         av_log(h->s.avctx, AV_LOG_DEBUG, "error, NO frame\n");
         return -1;

Index: mpeg12.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/mpeg12.c,v
retrieving revision 1.233
retrieving revision 1.234
diff -u -d -r1.233 -r1.234
--- mpeg12.c	21 Apr 2005 21:23:22 -0000	1.233
+++ mpeg12.c	24 Apr 2005 17:21:08 -0000	1.234
@@ -226,10 +226,10 @@
 
     if(find_frame_rate_index(s) < 0){
         if(s->strict_std_compliance >=0){
-            av_log(avctx, AV_LOG_ERROR, "MPEG1/2 doesnt support %d/%d fps\n", avctx->frame_rate, avctx->frame_rate_base);
+            av_log(avctx, AV_LOG_ERROR, "MPEG1/2 does not support %d/%d fps\n", avctx->frame_rate, avctx->frame_rate_base);
             return -1;
         }else{
-            av_log(avctx, AV_LOG_INFO, "MPEG1/2 doesnt support %d/%d fps, there may be AV sync issues\n", avctx->frame_rate, avctx->frame_rate_base);
+            av_log(avctx, AV_LOG_INFO, "MPEG1/2 does not support %d/%d fps, there may be AV sync issues\n", avctx->frame_rate, avctx->frame_rate_base);
         }
     }
     
@@ -1055,11 +1055,11 @@
 
     dprintf("decode_mb: x=%d y=%d\n", s->mb_x, s->mb_y);
 
-    assert(s->mb_skiped==0);
+    assert(s->mb_skipped==0);
 
     if (s->mb_skip_run-- != 0) {
         if(s->pict_type == I_TYPE){
-            av_log(s->avctx, AV_LOG_ERROR, "skiped MB in I frame at %d %d\n", s->mb_x, s->mb_y);
+            av_log(s->avctx, AV_LOG_ERROR, "skipped MB in I frame at %d %d\n", s->mb_x, s->mb_y);
             return -1;
         }
     
@@ -1078,7 +1078,7 @@
             s->last_mv[0][0][0] = s->last_mv[0][0][1] = 0;
             s->last_mv[0][1][0] = s->last_mv[0][1][1] = 0;
             s->field_select[0][0]= s->picture_structure - 1;
-            s->mb_skiped = 1;
+            s->mb_skipped = 1;
             s->current_picture.mb_type[ s->mb_x + s->mb_y*s->mb_stride ]= MB_TYPE_SKIP | MB_TYPE_L0 | MB_TYPE_16x16;
         } else {
             int mb_type;
@@ -1101,7 +1101,7 @@
 //            assert(s->current_picture.mb_type[ s->mb_x + s->mb_y*s->mb_stride - 1]&(MB_TYPE_16x16|MB_TYPE_16x8));
 
             if((s->mv[0][0][0]|s->mv[0][0][1]|s->mv[1][0][0]|s->mv[1][0][1])==0) 
-                s->mb_skiped = 1;
+                s->mb_skipped = 1;
         }
 
         return 0;

Index: faad.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/faad.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -d -r1.6 -r1.7
--- faad.c	24 Feb 2005 19:08:49 -0000	1.6
+++ faad.c	24 Apr 2005 17:21:08 -0000	1.7
@@ -158,7 +158,7 @@
     out = s->faacDecDecode(s->faac_handle, &frame_info, (unsigned char*)buf, (unsigned long)buf_size);
 
     if (frame_info.error > 0) {
-	av_log(avctx, AV_LOG_ERROR, "faac: frame decodinf failed: %s\n",
+	av_log(avctx, AV_LOG_ERROR, "faac: frame decoding failed: %s\n",
 		s->faacDecGetErrorMessage(frame_info.error));
         return 0;
     }

Index: ffv1.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/ffv1.c,v
retrieving revision 1.31
retrieving revision 1.32
diff -u -d -r1.31 -r1.32
--- ffv1.c	24 Feb 2005 16:39:03 -0000	1.31
+++ ffv1.c	24 Apr 2005 17:21:08 -0000	1.32
@@ -551,7 +551,7 @@
     int i;
 
     if(avctx->strict_std_compliance >= 0){
-        av_log(avctx, AV_LOG_ERROR, "this codec is under development, files encoded with it wont be decodeable with future versions!!!\n"
+        av_log(avctx, AV_LOG_ERROR, "this codec is under development, files encoded with it may not be decodeable with future versions!!!\n"
                "use vstrict=-1 / -strict -1 to use it anyway\n");
         return -1;
     }

Index: flac.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/flac.c,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -d -r1.17 -r1.18
--- flac.c	28 Feb 2005 05:27:21 -0000	1.17
+++ flac.c	24 Apr 2005 17:21:08 -0000	1.18
@@ -556,7 +556,7 @@
     skip_bits(&s->gb, 8);
     crc8= get_crc8(s->gb.buffer, get_bits_count(&s->gb)/8);
     if(crc8){
-        av_log(s->avctx, AV_LOG_ERROR, "header crc missmatch crc=%2X\n", crc8);
+        av_log(s->avctx, AV_LOG_ERROR, "header crc mismatch crc=%2X\n", crc8);
         return -1;
     }
     

Index: h263dec.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/h263dec.c,v
retrieving revision 1.165
retrieving revision 1.166
diff -u -d -r1.165 -r1.166
--- h263dec.c	6 Mar 2005 23:20:53 -0000	1.165
+++ h263dec.c	24 Apr 2005 17:21:08 -0000	1.166
@@ -199,7 +199,7 @@
             
             s->mv_dir = MV_DIR_FORWARD;
             s->mv_type = MV_TYPE_16X16;
-//            s->mb_skiped = 0;
+//            s->mb_skipped = 0;
 //printf("%d %d %06X\n", ret, get_bits_count(&s->gb), show_bits(&s->gb, 24));
             ret= s->decode_mb(s, s->block);
 
@@ -451,7 +451,7 @@
         }else if(s->codec_id==CODEC_ID_H263){
             next= h263_find_frame_end(&s->parse_context, buf, buf_size);
         }else{
-            av_log(s->avctx, AV_LOG_ERROR, "this codec doesnt support truncated bitstreams\n");
+            av_log(s->avctx, AV_LOG_ERROR, "this codec does not support truncated bitstreams\n");
             return -1;
         }
         
@@ -503,7 +503,7 @@
         ret = h263_decode_picture_header(s);
     }
     
-    if(ret==FRAME_SKIPED) return get_consumed_bytes(s, buf_size);
+    if(ret==FRAME_SKIPPED) return get_consumed_bytes(s, buf_size);
 
     /* skip if the header was thrashed */
     if (ret < 0){

Index: huffyuv.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/huffyuv.c,v
retrieving revision 1.60
retrieving revision 1.61
diff -u -d -r1.60 -r1.61
--- huffyuv.c	6 Mar 2005 23:20:53 -0000	1.60
+++ huffyuv.c	24 Apr 2005 17:21:08 -0000	1.61
@@ -542,7 +542,7 @@
         if(s->interlaced != ( s->height > 288 ))
             av_log(avctx, AV_LOG_INFO, "using huffyuv 2.2.0 or newer interlacing flag\n");
     }else if(avctx->strict_std_compliance>=0){
-        av_log(avctx, AV_LOG_ERROR, "This codec is under development; files encoded with it may not be decodeable with future versions!!! Set vstrict=-1 / -strict -1 to use it anyway.\n");
+        av_log(avctx, AV_LOG_ERROR, "This codec is under development; files encoded with it may not be decodable with future versions!!! Set vstrict=-1 / -strict -1 to use it anyway.\n");
         return -1;
     }
     
@@ -827,7 +827,7 @@
             p->data[0][1]= get_bits(&s->gb, 8);
             p->data[0][0]= get_bits(&s->gb, 8);
             
-            av_log(avctx, AV_LOG_ERROR, "YUY2 output isnt implemenetd yet\n");
+            av_log(avctx, AV_LOG_ERROR, "YUY2 output is not implemented yet\n");
             return -1;
         }else{
         
@@ -996,14 +996,14 @@
                         }
                     }
                 }
-                draw_slice(s, height); // just 1 large slice as this isnt possible in reverse order
+                draw_slice(s, height); // just 1 large slice as this is not possible in reverse order
                 break;
             default:
                 av_log(avctx, AV_LOG_ERROR, "prediction type not supported!\n");
             }
         }else{
 
-            av_log(avctx, AV_LOG_ERROR, "BGR24 output isnt implemenetd yet\n");
+            av_log(avctx, AV_LOG_ERROR, "BGR24 output is not implemented yet\n");
             return -1;
         }
     }

Index: rv10.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/rv10.c,v
retrieving revision 1.68
retrieving revision 1.69
diff -u -d -r1.68 -r1.69
--- rv10.c	21 Apr 2005 21:27:03 -0000	1.68
+++ rv10.c	24 Apr 2005 17:21:09 -0000	1.69
@@ -468,8 +468,8 @@
             s->time= seq;
             s->pb_time= s->pp_time - (s->last_non_b_time - s->time);
             if(s->pp_time <=s->pb_time || s->pp_time <= s->pp_time - s->pb_time || s->pp_time<=0){
-                av_log(s->avctx, AV_LOG_DEBUG, "messed up order, seeking?, skiping current b frame\n");
-                return FRAME_SKIPED;
+                av_log(s->avctx, AV_LOG_DEBUG, "messed up order, possible from seeking? skipping current b frame\n");
+                return FRAME_SKIPPED;
             }
         }
     }

Index: snow.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/snow.c,v
retrieving revision 1.57
retrieving revision 1.58
diff -u -d -r1.57 -r1.58
--- snow.c	17 Apr 2005 09:27:53 -0000	1.57
+++ snow.c	24 Apr 2005 17:21:09 -0000	1.58
@@ -3338,7 +3338,7 @@
     int plane_index;
 
     if(avctx->strict_std_compliance >= 0){
-        av_log(avctx, AV_LOG_ERROR, "this codec is under development, files encoded with it wont be decodeable with future versions!!!\n"
+        av_log(avctx, AV_LOG_ERROR, "this codec is under development, files encoded with it may not be decodable with future versions!!!\n"
                "use vstrict=-1 / -strict -1 to use it anyway\n");
         return -1;
     }

Index: wmv2.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/wmv2.c,v
retrieving revision 1.29
retrieving revision 1.30
diff -u -d -r1.29 -r1.30
--- wmv2.c	24 Feb 2005 19:08:50 -0000	1.29
+++ wmv2.c	24 Apr 2005 17:21:09 -0000	1.30
@@ -474,7 +474,7 @@
 //        return wmv2_decode_j_picture(w); //FIXME
 
     if(w->j_type){
-        av_log(s->avctx, AV_LOG_ERROR, "J-type picture isnt supported\n");
+        av_log(s->avctx, AV_LOG_ERROR, "J-type picture is not supported\n");
         return -1;
     }
 
@@ -723,7 +723,7 @@
             s->mv_type = MV_TYPE_16X16;
             s->mv[0][0][0] = 0;
             s->mv[0][0][1] = 0;
-            s->mb_skiped = 1;
+            s->mb_skipped = 1;
             w->hshift=0;
             return 0;
         }

Index: motion_est.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/motion_est.c,v
retrieving revision 1.103
retrieving revision 1.104
diff -u -d -r1.103 -r1.104
--- motion_est.c	26 Mar 2005 18:10:44 -0000	1.103
+++ motion_est.c	24 Apr 2005 17:21:09 -0000	1.104
@@ -1300,7 +1300,7 @@
             c->sub_motion_search(s, &mx, &my, dmin, 0, 0, 0, 16);
             if(s->flags&CODEC_FLAG_MV0)
                 if(mx || my)
-                    mb_type |= CANDIDATE_MB_TYPE_SKIPED; //FIXME check difference
+                    mb_type |= CANDIDATE_MB_TYPE_SKIPPED; //FIXME check difference
         }else{
             mx <<=shift;
             my <<=shift;

Index: error_resilience.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/error_resilience.c,v
retrieving revision 1.28
retrieving revision 1.29
diff -u -d -r1.28 -r1.29
--- error_resilience.c	19 Mar 2005 13:10:09 -0000	1.28
+++ error_resilience.c	24 Apr 2005 17:21:10 -0000	1.29
@@ -346,7 +346,7 @@
                 s->mv_dir = MV_DIR_FORWARD;
                 s->mb_intra=0;
                 s->mv_type = MV_TYPE_16X16;
-                s->mb_skiped=0;
+                s->mb_skipped=0;
 
 		s->dsp.clear_blocks(s->block[0]);
 
@@ -474,7 +474,7 @@
                     s->mv_dir = MV_DIR_FORWARD;
                     s->mb_intra=0;
                     s->mv_type = MV_TYPE_16X16;
-                    s->mb_skiped=0;
+                    s->mb_skipped=0;
 
 		    s->dsp.clear_blocks(s->block[0]);
 
@@ -858,7 +858,7 @@
             
             s->mv_dir = MV_DIR_FORWARD;
             s->mb_intra=0;
-            s->mb_skiped=0;
+            s->mb_skipped=0;
             if(IS_8X8(mb_type)){
                 int mb_index= mb_x*2 + mb_y*2*s->b8_stride;
                 int j;
@@ -897,7 +897,7 @@
                 s->mv_dir = MV_DIR_FORWARD|MV_DIR_BACKWARD;
                 s->mb_intra=0;
                 s->mv_type = MV_TYPE_16X16;
-                s->mb_skiped=0;
+                s->mb_skipped=0;
                 
                 if(s->pp_time){
                     int time_pp= s->pp_time;

Index: msmpeg4.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/msmpeg4.c,v
retrieving revision 1.85
retrieving revision 1.86
diff -u -d -r1.85 -r1.86
--- msmpeg4.c	18 Apr 2005 20:07:48 -0000	1.85
+++ msmpeg4.c	24 Apr 2005 17:21:10 -0000	1.86
@@ -1492,7 +1492,7 @@
                 s->mv_type = MV_TYPE_16X16;
                 s->mv[0][0][0] = 0;
                 s->mv[0][0][1] = 0;
-                s->mb_skiped = 1;
+                s->mb_skipped = 1;
                 return 0;
             }
         }
@@ -1580,7 +1580,7 @@
                 s->mv_type = MV_TYPE_16X16;
                 s->mv[0][0][0] = 0;
                 s->mv[0][0][1] = 0;
-                s->mb_skiped = 1;
+                s->mb_skipped = 1;
                 *mb_type_ptr = MB_TYPE_SKIP | MB_TYPE_L0 | MB_TYPE_16x16;
 
                 return 0;

Index: xvmcvideo.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/xvmcvideo.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -d -r1.10 -r1.11
--- xvmcvideo.c	1 Oct 2004 12:31:11 -0000	1.10
+++ xvmcvideo.c	24 Apr 2005 17:21:10 -0000	1.11
@@ -148,7 +148,7 @@
     }
 
    //MC doesn't skip blocks
-    s->mb_skiped = 0;
+    s->mb_skipped = 0;
 
 
    // do I need to export quant when I could not perform postprocessing?

Index: h261.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/h261.c,v
retrieving revision 1.23
retrieving revision 1.24
diff -u -d -r1.23 -r1.24
--- h261.c	23 Jan 2005 18:09:06 -0000	1.23
+++ h261.c	24 Apr 2005 17:21:10 -0000	1.24
@@ -541,7 +541,7 @@
         s->current_picture.mb_type[xy]= MB_TYPE_SKIP | MB_TYPE_16x16 | MB_TYPE_L0;
         s->mv[0][0][0] = 0;
         s->mv[0][0][1] = 0;
-        s->mb_skiped = 1;
+        s->mb_skipped = 1;
         h->mtype &= ~MB_TYPE_H261_FIL;
 
         MPV_decode_mb(s, s->block);

Index: ratecontrol.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/ratecontrol.c,v
retrieving revision 1.47
retrieving revision 1.48
diff -u -d -r1.47 -r1.48
--- ratecontrol.c	2 Feb 2005 19:33:48 -0000	1.47
+++ ratecontrol.c	24 Apr 2005 17:21:10 -0000	1.48
@@ -79,7 +79,7 @@
         rcc->entry = (RateControlEntry*)av_mallocz(i*sizeof(RateControlEntry));
         rcc->num_entries= i;
         
-        /* init all to skiped p frames (with b frames we might have a not encoded frame at the end FIXME) */
+        /* init all to skipped p frames (with b frames we might have a not encoded frame at the end FIXME) */
         for(i=0; i<rcc->num_entries; i++){
             RateControlEntry *rce= &rcc->entry[i];
             rce->pict_type= rce->new_pict_type=P_TYPE;

Index: mpegvideo.h
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/mpegvideo.h,v
retrieving revision 1.221
retrieving revision 1.222
diff -u -d -r1.221 -r1.222
--- mpegvideo.h	4 Mar 2005 12:47:38 -0000	1.221
+++ mpegvideo.h	24 Apr 2005 17:21:10 -0000	1.222
@@ -29,7 +29,7 @@
 #include "dsputil.h"
 #include "bitstream.h"
 
-#define FRAME_SKIPED 100 ///< return value for header parsers if frame is not coded
+#define FRAME_SKIPPED 100 ///< return value for header parsers if frame is not coded
 
 enum OutputFormat {
     FMT_MPEG1,
@@ -203,7 +203,7 @@
  */
 typedef struct MotionEstContext{
     AVCodecContext *avctx;
-    int skip;                          ///< set if ME is skiped for the current MB 
+    int skip;                          ///< set if ME is skipped for the current MB 
     int co_located_mv[4][2];           ///< mv from last p frame for direct mode ME 
     int direct_basis_mv[4][2];
     uint8_t *scratchpad;               ///< data area for the me algo, so that the ME doesnt need to malloc/free 
@@ -350,7 +350,7 @@
     int ac_pred;
     uint8_t *prev_pict_types;     ///< previous picture types in bitstream order, used for mb skip 
 #define PREV_PICT_TYPES_BUFFER_SIZE 256
-    int mb_skiped;                ///< MUST BE SET only during DECODING 
+    int mb_skipped;                ///< MUST BE SET only during DECODING 
     uint8_t *mbskip_table;        /**< used to avoid copy if macroblock skipped (for black regions for example) 
                                    and used for b-frame encoding & decoding (contains skip table of next P Frame) */
     uint8_t *mbintra_table;       ///< used to avoid setting {ac, dc, cbp}-pred stuff to zero on inter MB decoding 
@@ -378,7 +378,7 @@
     /* motion compensation */
     int unrestricted_mv;        ///< mv can point outside of the coded picture 
     int h263_long_vectors;      ///< use horrible h263v1 long vector mode 
-    int decode;                 ///< if 0 then decoding will be skiped (for encoding b frames for example)
+    int decode;                 ///< if 0 then decoding will be skipped (for encoding b frames for example)
 
     DSPContext dsp;             ///< pointers for accelerated dsp fucntions 
     int f_code;                 ///< forward MV resolution 
@@ -427,7 +427,7 @@
     int no_rounding;  /**< apply no rounding to motion compensation (MPEG4, msmpeg4, ...) 
                         for b-frames rounding mode is allways 0 */
 
-    int hurry_up;     /**< when set to 1 during decoding, b frames will be skiped
+    int hurry_up;     /**< when set to 1 during decoding, b frames will be skipped
                          when set to 2 idct/dequant will be skipped too */
                         
     /* macroblock layer */
@@ -438,7 +438,7 @@
 #define CANDIDATE_MB_TYPE_INTRA    0x01
 #define CANDIDATE_MB_TYPE_INTER    0x02
 #define CANDIDATE_MB_TYPE_INTER4V  0x04
-#define CANDIDATE_MB_TYPE_SKIPED   0x08
+#define CANDIDATE_MB_TYPE_SKIPPED   0x08
 //#define MB_TYPE_GMC      0x10
 
 #define CANDIDATE_MB_TYPE_DIRECT   0x10

Index: avcodec.h
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/avcodec.h,v
retrieving revision 1.390
retrieving revision 1.391
diff -u -d -r1.390 -r1.391
--- avcodec.h	20 Apr 2005 09:40:04 -0000	1.390
+++ avcodec.h	24 Apr 2005 17:21:10 -0000	1.391
@@ -1691,14 +1691,14 @@
      int nsse_weight;
 
     /**
-     * number of macroblock rows at the top which are skiped.
+     * number of macroblock rows at the top which are skipped.
      * - encoding: unused
      * - decoding: set by user
      */
      int skip_top;
 
     /**
-     * number of macroblock rows at the bottom which are skiped.
+     * number of macroblock rows at the bottom which are skipped.
      * - encoding: unused
      * - decoding: set by user
      */





More information about the ffmpeg-cvslog mailing list
Index: h263.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/h263.c,v
retrieving revision 1.274
retrieving revision 1.275
diff -u -d -r1.274 -r1.275
--- h263.c	18 Apr 2005 20:07:48 -0000	1.274
+++ h263.c	24 Apr 2005 17:21:08 -0000	1.275
@@ -619,7 +619,7 @@
     const int wrap = s->b8_stride;
     const int xy = s->block_index[0];
     
-    s->current_picture.mbskip_table[mb_xy]= s->mb_skiped; 
+    s->current_picture.mbskip_table[mb_xy]= s->mb_skipped; 
 
     if(s->mv_type != MV_TYPE_8X8){
         int motion_x, motion_y;
@@ -855,7 +855,7 @@
             assert((s->dquant&1)==0);
             assert(mb_type>=0);
 
             /* nothing to do if this MB was skiped in the next P Frame */
             if(s->next_picture.mbskip_table[s->mb_y * s->mb_stride + s->mb_x]){ //FIXME avoid DCT & ...
                 s->skip_count++;
                 s->mv[0][0][0]= 
@@ -864,7 +864,7 @@
                 s->mv[1][0][1]= 0;
                 s->mv_dir= MV_DIR_FORWARD; //doesnt matter
                 s->qscale -= s->dquant;
-//                s->mb_skiped=1;
+//                s->mb_skipped=1;
 
                 return;
             }
@@ -990,7 +990,7 @@
                     offset= x + y*s->linesize;
                     p_pic= s->new_picture.data[0] + offset;
                     
-                    s->mb_skiped=1;
+                    s->mb_skipped=1;
                     for(i=0; i<s->max_b_frames; i++){
                         uint8_t *b_pic;
                         int diff;
@@ -1001,14 +1001,14 @@
                         b_pic= pic->data[0] + offset + 16; //FIXME +16
 			diff= s->dsp.sad[0](NULL, p_pic, b_pic, s->linesize, 16);
                         if(diff>s->qscale*70){ //FIXME check that 70 is optimal
-                            s->mb_skiped=0;
+                            s->mb_skipped=0;
                             break;
                         }
                     }
                 }else
-                    s->mb_skiped=1; 
+                    s->mb_skipped=1; 
 
-                if(s->mb_skiped==1){
+                if(s->mb_skipped==1){
                     /* skip macroblock */
                     put_bits(&s->pb, 1, 1);
 
@@ -3211,7 +3211,7 @@
     }
     if(s->pict_type == B_TYPE){
         while(s->next_picture.mbskip_table[ s->mb_index2xy[ mb_num ] ]) mb_num++;
-        if(mb_num >= s->mb_num) return -1; // slice contains just skiped MBs which where allready decoded
+        if(mb_num >= s->mb_num) return -1; // slice contains just skipped MBs which where allready decoded
     }
     
     s->mb_x= mb_num % s->mb_width;
@@ -3729,10 +3729,10 @@
             s->mv_type = MV_TYPE_16X16;
             if(s->pict_type==S_TYPE && s->vol_sprite_usage==GMC_SPRITE){
                 s->mcsel=1;
-                s->mb_skiped = 0;
+                s->mb_skipped = 0;
             }else{
                 s->mcsel=0;
-                s->mb_skiped = 1;
+                s->mb_skipped = 1;
             }
         }else if(s->mb_intra){
             s->ac_pred = IS_ACPRED(s->current_picture.mb_type[xy]);
@@ -3910,7 +3910,7 @@
                 s->current_picture.mb_type[xy]= MB_TYPE_SKIP | MB_TYPE_16x16 | MB_TYPE_L0;
                 s->mv[0][0][0] = 0;
                 s->mv[0][0][1] = 0;
-                s->mb_skiped = !(s->obmc | s->loop_filter);
+                s->mb_skipped = !(s->obmc | s->loop_filter);
                 goto end;
             }
             cbpc = get_vlc2(&s->gb, inter_MCBPC_vlc.table, INTER_MCBPC_VLC_BITS, 2);
@@ -4175,13 +4175,13 @@
                     s->mv[0][0][0]= get_amv(s, 0);
                     s->mv[0][0][1]= get_amv(s, 1);
 
-                    s->mb_skiped = 0;
+                    s->mb_skipped = 0;
                 }else{
                     s->current_picture.mb_type[xy]= MB_TYPE_SKIP | MB_TYPE_16x16 | MB_TYPE_L0;
                     s->mcsel=0;
                     s->mv[0][0][0] = 0;
                     s->mv[0][0][1] = 0;
-                    s->mb_skiped = 1;
+                    s->mb_skipped = 1;
                 }
                 goto end;
             }
@@ -4294,9 +4294,9 @@
         }
 
         /* if we skipped it in the future P Frame than skip it now too */
-        s->mb_skiped= s->next_picture.mbskip_table[s->mb_y * s->mb_stride + s->mb_x]; // Note, skiptab=0 if last was GMC
+        s->mb_skipped= s->next_picture.mbskip_table[s->mb_y * s->mb_stride + s->mb_x]; // Note, skiptab=0 if last was GMC
 
-        if(s->mb_skiped){
+        if(s->mb_skipped){
                 /* skip mb */
             for(i=0;i<6;i++)
                 s->block_last_index[i] = -1;
@@ -5586,7 +5586,7 @@
         if (get_bits1(gb) == 1) {   /* not_8_bit */
             s->quant_precision = get_bits(gb, 4); /* quant_precision */
             if(get_bits(gb, 4)!=8) av_log(s->avctx, AV_LOG_ERROR, "N-bit not supported\n"); /* bits_per_pixel */
-            if(s->quant_precision!=5) av_log(s->avctx, AV_LOG_ERROR, "quant precission %d\n", s->quant_precision);
+            if(s->quant_precision!=5) av_log(s->avctx, AV_LOG_ERROR, "quant precision %d\n", s->quant_precision);
         } else {
             s->quant_precision = 5;
         }
@@ -5778,7 +5778,7 @@
 
     s->pict_type = get_bits(gb, 2) + I_TYPE;	/* pict type: I = 0 , P = 1 */
     if(s->pict_type==B_TYPE && s->low_delay && s->vol_control_parameters==0 && !(s->flags & CODEC_FLAG_LOW_DELAY)){
-        av_log(s->avctx, AV_LOG_ERROR, "low_delay flag set, but shouldnt, clearing it\n");
+        av_log(s->avctx, AV_LOG_ERROR, "low_delay flag incorrectly, clearing it\n");
         s->low_delay=0;
     }
  
@@ -5799,7 +5799,7 @@
     check_marker(gb, "before time_increment");
     
     if(s->time_increment_bits==0){
-        av_log(s->avctx, AV_LOG_ERROR, "hmm, seems the headers arnt complete, trying to guess time_increment_bits\n");
+        av_log(s->avctx, AV_LOG_ERROR, "hmm, seems the headers are not complete, trying to guess time_increment_bits\n");
 
         for(s->time_increment_bits=1 ;s->time_increment_bits<16; s->time_increment_bits++){
             if(show_bits(gb, s->time_increment_bits+1)&1) break;
@@ -5830,8 +5830,8 @@
         s->time= (s->last_time_base + time_incr)*s->time_increment_resolution + time_increment;
         s->pb_time= s->pp_time - (s->last_non_b_time - s->time);
         if(s->pp_time <=s->pb_time || s->pp_time <= s->pp_time - s->pb_time || s->pp_time<=0){
-//            printf("messed up order, seeking?, skiping current b frame\n");
-            return FRAME_SKIPED;
+//            printf("messed up order, maybe after seeking? skipping current b frame\n");
+            return FRAME_SKIPPED;
         }
         
         if(s->t_frame==0) s->t_frame= s->pb_time;
@@ -5853,7 +5853,7 @@
     if (get_bits1(gb) != 1){
         if(s->avctx->debug&FF_DEBUG_PICT_INFO)
             av_log(s->avctx, AV_LOG_ERROR, "vop not coded\n");
-        return FRAME_SKIPED;
+        return FRAME_SKIPPED;
     }
 //printf("time %d %d %d || %Ld %Ld %Ld\n", s->time_increment_bits, s->time_increment_resolution, s->time_base,
 //s->time, s->last_non_b_time, s->last_non_b_time - s->pp_time);  
@@ -6003,7 +6003,7 @@
         if(get_bits_count(gb) >= gb->size_in_bits){
             if(gb->size_in_bits==8 && (s->divx_version || s->xvid_build)){
                 av_log(s->avctx, AV_LOG_ERROR, "frame skip %d\n", gb->size_in_bits);
-                return FRAME_SKIPED; //divx bug
+                return FRAME_SKIPPED; //divx bug
             }else
                 return -1; //end of stream
         }
@@ -6032,11 +6032,11 @@
             else if(startcode==0x1BB) av_log(s->avctx, AV_LOG_DEBUG, "FBA Object Plane start");
             else if(startcode==0x1BC) av_log(s->avctx, AV_LOG_DEBUG, "Mesh Object start");
             else if(startcode==0x1BD) av_log(s->avctx, AV_LOG_DEBUG, "Mesh Object Plane start");
-            else if(startcode==0x1BE) av_log(s->avctx, AV_LOG_DEBUG, "Still Textutre Object start");
-            else if(startcode==0x1BF) av_log(s->avctx, AV_LOG_DEBUG, "Textutre Spatial Layer start");
-            else if(startcode==0x1C0) av_log(s->avctx, AV_LOG_DEBUG, "Textutre SNR Layer start");
-            else if(startcode==0x1C1) av_log(s->avctx, AV_LOG_DEBUG, "Textutre Tile start");
-            else if(startcode==0x1C2) av_log(s->avctx, AV_LOG_DEBUG, "Textutre Shape Layer start");
+            else if(startcode==0x1BE) av_log(s->avctx, AV_LOG_DEBUG, "Still Texture Object start");
+            else if(startcode==0x1BF) av_log(s->avctx, AV_LOG_DEBUG, "Texture Spatial Layer start");
+            else if(startcode==0x1C0) av_log(s->avctx, AV_LOG_DEBUG, "Texture SNR Layer start");
+            else if(startcode==0x1C1) av_log(s->avctx, AV_LOG_DEBUG, "Texture Tile start");
+            else if(startcode==0x1C2) av_log(s->avctx, AV_LOG_DEBUG, "Texture Shape Layer start");
             else if(startcode==0x1C3) av_log(s->avctx, AV_LOG_DEBUG, "stuffing start");
             else if(startcode<=0x1C5) av_log(s->avctx, AV_LOG_DEBUG, "reserved");
             else if(startcode<=0x1FF) av_log(s->avctx, AV_LOG_DEBUG, "System start");
@@ -855,7 +855,7 @@
             assert(mb_type>=0);
 
-            /* nothing to do if this MB was skiped in the next P Frame */
+            /* nothing to do if this MB was skipped in the next P Frame */
             if(s->next_picture.mbskip_table[s->mb_y * s->mb_stride + s->mb_x]){ //FIXME avoid DCT & ...
                 s->skip_count++;

Index: vc9.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/vc9.c,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -d -r1.17 -r1.18
--- vc9.c	23 Feb 2005 17:24:17 -0000	1.17
+++ vc9.c	24 Apr 2005 17:21:09 -0000	1.18
@@ -891,7 +891,7 @@
     if (bp->data) av_freep(&bp->data);
 }
 
 /** Decode rows by checking if they are skiped
  * @param plane Buffer to store decoded bits
  * @param[in] width Width of this buffer
  * @param[in] height Height of this buffer
@@ -910,7 +910,7 @@
     }
 }
 
 /** Decode columns by checking if they are skiped
  * @param plane Buffer to store decoded bits
  * @param[in] width Width of this buffer
  * @param[in] height Height of this buffer
@@ -1126,14 +1126,14 @@
     if (v->profile == PROFILE_SIMPLE)
     {
         av_log(v->s.avctx, AV_LOG_ERROR, "Found a B frame while in Simple Profile!\n");
-        return FRAME_SKIPED;
+        return FRAME_SKIPPED;
     }
     v->bfraction = vc9_bfraction_lut[get_vlc2(gb, vc9_bfraction_vlc.table,
                                               VC9_BFRACTION_VLC_BITS, 2)];
     if (v->bfraction < -1)
     {
         av_log(v->s.avctx, AV_LOG_ERROR, "Invalid BFRaction\n");
-        return FRAME_SKIPED;
+        return FRAME_SKIPPED;
     }
     else if (!v->bfraction)
     {
@@ -1474,7 +1474,7 @@
     case B_TYPE: status = decode_b_picture_primary_header(v); break;
     }
 
-    if (status == FRAME_SKIPED)
+    if (status == FRAME_SKIPPED)
     {
       av_log(v->s.avctx, AV_LOG_INFO, "Skipping frame...\n");
       return status;
@@ -1499,7 +1499,7 @@
     case BI_TYPE:
     case I_TYPE: break; //Nothing needed as it's done in the epilog
     }
-    if (status < 0) return FRAME_SKIPED;
+    if (status < 0) return FRAME_SKIPPED;
 
     /* AC Syntax */
     v->c_ac_table_index = decode012(gb);
@@ -1540,7 +1540,7 @@
     }
 
     type = get_prefix(gb, 0, 4);
-    if (type > 4 || type < 0) return FRAME_SKIPED;
+    if (type > 4 || type < 0) return FRAME_SKIPPED;
     v->s.pict_type = type_table[type];
     av_log(v->s.avctx, AV_LOG_INFO, "AP Frame Type: %i\n", v->s.pict_type);
 
@@ -1578,7 +1578,7 @@
     case I_TYPE: if (decode_i_picture_primary_header(v) < 0) return -1;
     case P_TYPE: if (decode_p_picture_primary_header(v) < 0) return -1;
     case BI_TYPE:
-    case B_TYPE: if (decode_b_picture_primary_header(v) < 0) return FRAME_SKIPED;
+    case B_TYPE: if (decode_b_picture_primary_header(v) < 0) return FRAME_SKIPPED;
     default: return -1;
     }
 }
@@ -1599,7 +1599,7 @@
     case BI_TYPE:
     case I_TYPE: status = decode_i_picture_secondary_header(v); break; 
     }
-    if (status<0) return FRAME_SKIPED;
+    if (status<0) return FRAME_SKIPPED;
 
     /* AC Syntax */
     v->c_ac_table_index = decode012(gb);
@@ -2367,7 +2367,7 @@
 {
     VC9Context *v = avctx->priv_data;
     MpegEncContext *s = &v->s;
-    int ret = FRAME_SKIPED, len;
+    int ret = FRAME_SKIPPED, len;
     AVFrame *pict = data;
     uint8_t *tmp_buf;
     v->s.avctx = avctx;
@@ -2470,7 +2470,7 @@
     else
 #endif
         ret= standard_decode_picture_primary_header(v);
-    if (ret == FRAME_SKIPED) return buf_size;
+    if (ret == FRAME_SKIPPED) return buf_size;
     /* skip if the header was thrashed */
     if (ret < 0){
         av_log(s->avctx, AV_LOG_ERROR, "header damaged\n");
@@ -2518,7 +2518,7 @@
     else
 #endif
         ret = standard_decode_picture_secondary_header(v);
-    if (ret<0) return FRAME_SKIPED; //FIXME Non fatal for now
+    if (ret<0) return FRAME_SKIPPED; //FIXME Non fatal for now
 
     //We consider the image coded in only one slice
 #if HAS_ADVANCED_PROFILE
@@ -2530,15 +2530,15 @@
             case P_TYPE: ret = decode_p_mbs(v); break;
             case B_TYPE:
             case BI_TYPE: ret = decode_b_mbs(v); break;
-            default: ret = FRAME_SKIPED;
+            default: ret = FRAME_SKIPPED;
         }
-        if (ret == FRAME_SKIPED) return buf_size; //We ignore for now failures
+        if (ret == FRAME_SKIPPED) return buf_size; //We ignore for now failures
     }
     else
 #endif
     {
         ret = standard_decode_mbs(v);
-        if (ret == FRAME_SKIPED) return buf_size;
+        if (ret == FRAME_SKIPPED) return buf_size;
     }
 
     ff_er_frame_end(s);
@@ -891,7 +891,7 @@
 }
 
-/** Decode rows by checking if they are skiped
+/** Decode rows by checking if they are skipped
  * @param plane Buffer to store decoded bits
  * @param[in] width Width of this buffer
@@ -910,7 +910,7 @@
 }
 
-/** Decode columns by checking if they are skiped
+/** Decode columns by checking if they are skipped
  * @param plane Buffer to store decoded bits
  * @param[in] width Width of this buffer

Index: mpegvideo.c
===================================================================
RCS file: /cvsroot/ffmpeg/ffmpeg/libavcodec/mpegvideo.c,v
retrieving revision 1.475
retrieving revision 1.476
diff -u -d -r1.475 -r1.476
--- mpegvideo.c	24 Apr 2005 11:13:49 -0000	1.475
+++ mpegvideo.c	24 Apr 2005 17:21:09 -0000	1.476
@@ -409,7 +409,7 @@
     memmove(s->prev_pict_types+1, s->prev_pict_types, PREV_PICT_TYPES_BUFFER_SIZE-1);
     s->prev_pict_types[0]= s->pict_type;
     if(pic->age < PREV_PICT_TYPES_BUFFER_SIZE && s->prev_pict_types[pic->age] == B_TYPE)
-        pic->age= INT_MAX; // skiped MBs in b frames are quite rare in mpeg1/2 and its a bit tricky to skip them anyway
+        pic->age= INT_MAX; // skipped MBs in b frames are quite rare in mpeg1/2 and its a bit tricky to skip them anyway
     
     return 0;
 fail: //for the CHECKED_ALLOCZ macro
@@ -1444,7 +1444,7 @@
 {
     int i;
     AVFrame *pic;
-    s->mb_skiped = 0;
+    s->mb_skipped = 0;
 
     assert(s->last_picture_ptr==NULL || s->out_format != FMT_H264 || s->codec_id == CODEC_ID_SVQ3);
 
@@ -3227,7 +3227,7 @@
         const int mot_stride= s->b8_stride;
         const int mot_xy= mb_x*2 + mb_y*2*mot_stride;
 
-        assert(!s->mb_skiped);
+        assert(!s->mb_skipped);
                 
         memcpy(mv_cache[1][1], s->current_picture.motion_val[0][mot_xy           ], sizeof(int16_t)*4);
         memcpy(mv_cache[2][1], s->current_picture.motion_val[0][mot_xy+mot_stride], sizeof(int16_t)*4);
@@ -3699,11 +3699,11 @@
 
             assert(age);
 
-            if (s->mb_skiped) {
-                s->mb_skiped= 0;
+            if (s->mb_skipped) {
+                s->mb_skipped= 0;
                 assert(s->pict_type!=I_TYPE);
  
-                (*mbskip_ptr) ++; /* indicate that this time we skiped it */
+                (*mbskip_ptr) ++; /* indicate that this time we skipped it */
                 if(*mbskip_ptr >99) *mbskip_ptr= 99;
 
                 /* if previous was skipped too, then nothing to do !  */
@@ -4374,7 +4374,7 @@
     d->misc_bits= s->misc_bits;
     d->last_bits= 0;
 
-    d->mb_skiped= 0;
+    d->mb_skipped= 0;
     d->qscale= s->qscale;
     d->dquant= s->dquant;
 }
@@ -4401,7 +4401,7 @@
     d->misc_bits= s->misc_bits;
 
     d->mb_intra= s->mb_intra;
-    d->mb_skiped= s->mb_skiped;
+    d->mb_skipped= s->mb_skipped;
     d->mv_type= s->mv_type;
     d->mv_dir= s->mv_dir;
     d->pb= s->pb;
@@ -4773,7 +4773,7 @@
                 s->first_slice_line=0; 
             }
 
-            s->mb_skiped=0;
+            s->mb_skipped=0;
             s->dquant=0; //only for QP_RD
 
             if(mb_type & (mb_type-1) || (s->flags & CODEC_FLAG_QP_RD)){ // more than 1 MB type possible or CODEC_FLAG_QP_RD
@@ -4810,13 +4810,13 @@
                     encode_mb_hq(s, &backup_s, &best_s, CANDIDATE_MB_TYPE_INTER_I, pb, pb2, tex_pb, 
                                  &dmin, &next_block, 0, 0);
                 }
-                if(mb_type&CANDIDATE_MB_TYPE_SKIPED){
+                if(mb_type&CANDIDATE_MB_TYPE_SKIPPED){
                     s->mv_dir = MV_DIR_FORWARD;
                     s->mv_type = MV_TYPE_16X16;
                     s->mb_intra= 0;
                     s->mv[0][0][0] = 0;
                     s->mv[0][0][1] = 0;
-                    encode_mb_hq(s, &backup_s, &best_s, CANDIDATE_MB_TYPE_SKIPED, pb, pb2, tex_pb, 
+                    encode_mb_hq(s, &backup_s, &best_s, CANDIDATE_MB_TYPE_SKIPPED, pb, pb2, tex_pb, 
                                  &dmin, &next_block, s->mv[0][0][0], s->mv[0][0][1]);
                 }
                 if(mb_type&CANDIDATE_MB_TYPE_INTER4V){                 
